/**
 * This class implements a simple cdata generator that produces random
 * almost-readable text according to the grammar specified by the
 * TPC-H standarnd
 *
 * This code is provided as part of ToXgene - (c) 2001 University of Toronto
 * and IBM Corporation.
 *
 * @author Denilson Barbosa
 * @version 1.0
 */

package util.cdata.tpch;

import genes.literals.Cdata;
import java.util.Random;

public class Text implements Cdata{
	private static Random pick;
	private static String result;
	
	public Text(){

	}
	
	/**
	 * Specifies a seed for the random generator so that repeated
	 * executions always produce the same content, if the same seed is
	 * provided.
	 */
	public void setRandomSeed(int seed){
		pick = new Random(seed);
	}
	
	/**
	 * Generates random text that is at most @param length characters
	 * long if @param lenght is different than -1.
	 */
  public String getCdata(int length){
		if (length == -1){
			// this is dangerous: very long strings can be generated this way
			length = pick.nextInt(1024);
		}

		result = new String();
		do{
			result  = result.concat(sentence());
		}while(result.length() <= length);
	
		return result.substring(0,length);
  }

	/**
	 * Generates a random sentence.
	 */
  private String sentence(){
		int type = pick.nextInt(5);
		int terminator = pick.nextInt(nTerminators);

		switch (type){
		case 0:{
			return nounPhrase().concat(" ").concat(verbPhrase()).
				concat(terminators[terminator]);
		}
		case 1:{
			return nounPhrase().concat(" ").concat(verbPhrase()).concat(" ").
				concat(prepositionalPhrase()).concat(terminators[terminator]);
		}
		case 2:{
			return nounPhrase().concat(" ").concat(verbPhrase()).concat(" ").
				concat(nounPhrase()).concat(terminators[terminator]);
		}
		case 3:{
			return nounPhrase().concat(" ").concat(prepositionalPhrase()).
				concat(" ").concat(verbPhrase()).concat(" ").concat(nounPhrase()).
				concat(terminators[terminator]);
		}
		case 4:{
			return nounPhrase().concat(" ").concat(prepositionalPhrase()).
				concat(" ").concat(verbPhrase()).concat(" ").
				concat(prepositionalPhrase()).concat(terminators[terminator]);
		}
		}
		return null;
  }

  private String nounPhrase(){
		int type = pick.nextInt(4);

		switch (type){
		case 0:{
			return nouns[pick.nextInt(nNouns)];
		}
		case 1:{
			return (adjectives[pick.nextInt(nAdjectives)].concat(" ").
							concat(nouns[pick.nextInt(nNouns)]));
		}
		case 2:{
			return (adjectives[pick.nextInt(nAdjectives)].concat(", ").
							concat(adjectives[pick.nextInt(nAdjectives)]).
							concat(" ").concat(nouns[pick.nextInt(nNouns)]));
		}
		case 3:
			return (adverbs[pick.nextInt(nAdverbs)].concat(" ").
							concat(adjectives[pick.nextInt(nAdjectives)]).
							concat(" ").concat(nouns[pick.nextInt(nNouns)]));
		}
		return null;
  }

  private String verbPhrase(){
		int type = pick.nextInt(4);

		switch (type){
		case 0:{
			return verbs[pick.nextInt(nVerbs)];
		}
		case 1:{
			return (auxiliaries[pick.nextInt(nAuxiliaries)].concat(" ").
							concat(verbs[pick.nextInt(nVerbs)]));
		}
		case 2:{
			return (verbs[pick.nextInt(nVerbs)].concat(" ").
							concat(adverbs[pick.nextInt(nAdverbs)]));
		}
		case 3:
			return (auxiliaries[pick.nextInt(nAuxiliaries)].concat(" ").
							concat(verbs[pick.nextInt(nVerbs)]).
							concat(" ").concat(adverbs[pick.nextInt(nAdverbs)]));
		}
		return null;
	
  }

  private String prepositionalPhrase(){
		return prepositions[pick.nextInt(nPrepositions)].concat(" the ").concat(nounPhrase());
  }

  private final static String[] nouns = {
		"foxes", "ideas", "theodolites", "pinto",
		"beans", "instructions", "dependencies", "excuses", "platelets",
		"asymptotes", "courts","dolphins", "multipliers", "sauternes", "warthogs",
		"frets", "dinos", "attainments", "somas", "Tiresias", "patterns", "forges",
		"braids", "hockey", "players", "frays", "warhorses", "dugouts", "notornis",
		"epitaphs", "pearls", "tithes", "waters", "orbits", "gifts", "sheaves",
		"depths", "sentiments", "decoys", "realms", "pains", "grouches",
		"escapades"};
	private final static int nNouns = nouns.length;

  private final static String[] verbs = {
		"sleep", "wake", "are", "cajole", "haggle",
		"nag", "use", "boost", "affix", "detect", "integrate", "maintain", "nod",
		"was", "lose", "sublate", "solve", "thrash", "promise", "engage", "hinder",
		"print", "x-ray", "breach", "eat", "grow", "impress", "mold", "poach",
		"serve", "run", "dazzle", "snooze", "doze", "unwind", "kindle", "play",
		"hang", "belive", "doubt"};
  private final static int nVerbs = verbs.length;

  private final static String[] adjectives = {
		"furious", "sly", "careful", "blithe",
		"quick", "fluffy", "slow", "quiet", "ruthless", "thin", "close", "dogged",
		"daring", "brave", "stealthy", "permanent", "enticing", "idle", "busy",
		"regular", "final", "ironic", "even", "bold", "silent"};
  private final static int nAdjectives = adjectives.length;

  private final static String[] adverbs = {
		"sometimes", "always", "never", "furiously",
		"slyly", "carefully", "blithely", "quickly", "fluffily", "slowly",
		"quietly", "ruthlessly", "thinly", "closely", "doggedly", "daringly",
		"bravely", "stealthly", "permanently", "enticingly", "idly", "busily",
		"regularly", "finally", "ironically", "evenly", "boldly", "silently"};
  private final static int nAdverbs = adverbs.length;

  private final static String[] prepositions = {
		"about", "above", "according to",
		"across", "after", "against", "along", "alongside of", "among", "around",
		"at","atop", "before", "behind", "beneath", "beside", "besides", "between",
		"beyond", "bye", "despite", "during", "except", "for", "from", 
		"in place of","inside","instead of", "into", "near", "of", "on", "outside",
		"over", "past", "since", "through", "throughout", "to", "toward", "under",
		"until", "up", "upon", "without", "with", "within"}; 
	private final static int nPrepositions = prepositions.length;

  private final static String[] auxiliaries = {
		"do", "may", "might", "shall", "will",
		"would", "can", "could", "should", "ought to", "must", "will have to",
		"shall have to", "could have to", "should have to", "must have to", 
		"need to", "try to"};
  private final static int nAuxiliaries = auxiliaries.length;

  private final static String[] terminators = {".",";",":","?","!","--"};
  private final static int nTerminators = terminators.length;
}



