/**
 * This class implements a simple cdata generator that produces random
 * almost-readable text according to the grammar specified by the
 * XMark benchmark
 *
 * This code is provided as part of ToXgene - (c) 2001 University of Toronto
 * and IBM Corporation.
 *
 * @author Denilson Barbosa
 * @version 1.0
 */

package util.cdata.xmark;

import genes.literals.Cdata;
import java.util.Random;

public class Emails implements Cdata{
	private static Random pick;
	private static String result;
	private static boolean loaded = false;
	
	/**
	 * Constructor. The cdata content produced by this class uses
	 * strings stored in the @see FirstNames @see LastNames @see
	 * InetDomains.
	 */
	public Emails(){
		init();
	}

	/**
	 * Specifies a seed for the random generator so that repeated
	 * executions always produce the same content, if the same seed is
	 * provided.
	 */
	public void setRandomSeed(int seed){
		pick = new Random(seed);
	}
	
	/**
	 * Generates random text that is at most @param length characters
	 * long if @param lenght is different than -1.
	 */
  public String getCdata(int length){
		if (!loaded)
			init();

		result = FirstNames.data[pick.nextInt(FirstNames.len)];
		result += ".";
		result += LastNames.data[pick.nextInt(LastNames.len)];
		result += "@";
		result += InetDomains.data[pick.nextInt(InetDomains.len)];

		//length == -1 means that the string should not be trimmed
		if (length == -1){
			return result;
		}
		
		if (result.length() > length)
			return result.substring(0,length);
		else
			return result;
	}

	/**
	 * The initialization consists of loading the data into the other
	 * classes. We do not initialize @see InetDomain because its
	 * constants are declared explicitly (there are not too many of
	 * them).
	 */
	private void init(){
		FirstNames.init();
		LastNames.init();
		loaded = true;
	}
}
