/**
 * This class implements a simple cdata generator that produces random
 * almost-readable text according to the grammar specified by the
 * XMark benchmark
 *
 * This code is provided as part of ToXgene - (c) 2001 University of Toronto
 * and IBM Corporation.
 *
 * @author Denilson Barbosa
 * @version 1.0
 */

package util.cdata.xmark;

import genes.literals.Cdata;
import java.util.Random;

public class Provinces implements Cdata{
	private static Random pick;
	private static String result;

	/**
	 * Specifies a seed for the random generator so that repeated
	 * executions always produce the same content, if the same seed is
	 * provided.
	 */
	public void setRandomSeed(int seed){
		pick = new Random(seed);
	}
	
	/**
	 * Generates random text that is at most @param length characters
	 * long if @param lenght is different than -1.
	 */
	public String getCdata(int length){
		result = data[pick.nextInt(len)];

		//length == -1 means that the string should not be trimmed
		if (length == -1){
			return result;
		}

		if (result.length() > length)
			return result.substring(0,length);
		else
			return result;
	}

	/**
	 * These are the actual strings. We can declare this array here
	 * explicitly because there are not too many contants.
	 */
	public final static String[] data={
    "Alabama","Alaska","Arizona","Arkansas","California","Colorado",
    "Connecticut","Delaware","District Of Columbia","Florida","Georgia",
    "Hawaii","Idaho","Illinois","Indiana","Iowa","Kansas","Kentucky",
    "Louisiana","Maine","Maryland","Massachusetts","Michigan","Minnesota",
    "Mississipi","Missouri","Montana","Nebraska","Nevada","New Hampshire",
    "New Jersey","New Mexico","New York","North Carolina","North Dakota",
    "Ohio","Oklahoma","Oregon","Pennsylvania","Rhode Island",
    "South Carolina","South Dakota","Tennessee","Texas","Utah","Vermont",
    "Virginia","Washington","West Virginia","Wisconsin","Wyoming"
	};
	public final static int len = data.length;
}
